==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translation>Centrum</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Referentiepunt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translation>Bestemmingspunt</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Roteer</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Roteren opties</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Aantal kopieën</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Origineel verwijderen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>Origineel &amp;bewaren</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;Meerdere kopieën</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Hoek (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Gebruik huidige laag en &amp;attributen</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translation>Centrum</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Referentiepunt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translation>Bestemmingspunt</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Roteer</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Roteren opties</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Aantal kopieën</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Origineel verwijderen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>Origineel &amp;bewaren</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;Meerdere kopieën</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Hoek (a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>Definieer hoek met behulp van de muis cursor</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Gebruik huidige laag en &amp;attributen</translation>
    </message>
</context>
</TS>
